summaryrefslogtreecommitdiff
path: root/scripts/mysql_setpermission.sh
diff options
context:
space:
mode:
authorMonty <monty@mariadb.org>2014-08-03 15:12:53 +0300
committerMonty <monty@mariadb.org>2014-08-09 13:22:01 +0300
commitb4c74e2ab4c3676dd081421649de83ee0fb0f63c (patch)
treefb2d2f915ad4bb26842d378d80f04819e2b00bb3 /scripts/mysql_setpermission.sh
parent3bde13932ee53ee765a858e4413bc6c6af296d4b (diff)
downloadmariadb-git-b4c74e2ab4c3676dd081421649de83ee0fb0f63c.tar.gz
Change MySQL -> MariaDB inc scripts
Diffstat (limited to 'scripts/mysql_setpermission.sh')
-rw-r--r--scripts/mysql_setpermission.sh18
1 files changed, 9 insertions, 9 deletions
diff --git a/scripts/mysql_setpermission.sh b/scripts/mysql_setpermission.sh
index f23011a5ae6..50d7b116507 100644
--- a/scripts/mysql_setpermission.sh
+++ b/scripts/mysql_setpermission.sh
@@ -78,7 +78,7 @@ else
if ($opt_password eq '')
{
system "stty -echo";
- print "Password for user $opt_user to connect to MySQL: ";
+ print "Password for user $opt_user to connect to MariaDB: ";
$opt_password = <STDIN>;
chomp($opt_password);
system "stty echo";
@@ -86,7 +86,7 @@ if ($opt_password eq '')
}
# make the connection to MySQL
$dbh= DBI->connect("DBI:mysql:mysql:host=$sqlhost:port=$opt_port:mysql_socket=$opt_socket",$opt_user,$opt_password, {PrintError => 0}) ||
die("Can't make a connection to the mysql server.\n The error: $DBI::errstr");
@@ -106,7 +106,7 @@ sub q1 { # first question ...
while (! $end) {
print "#"x70;
print "\n";
- print "## Welcome to the permission setter $version for MySQL.\n";
+ print "## Welcome to the permission setter $version for MariaDB.\n";
print "## made by Luuk de Boer\n";
print "#"x70;
print "\n";
@@ -634,17 +634,17 @@ sub usage
{
print <<EOL;
----------------------------------------------------------------------
- The permission setter for MySQL.
+ The permission setter for MariaDB.
version: $version
made by: Luuk de Boer <luuk\@wxs.nl>
----------------------------------------------------------------------
The permission setter is a little program which can help you add users
-or databases or change passwords in MySQL. Keep in mind that we don't
-check permissions which already been set in MySQL. So if you can't
-connect to MySQL using the permission you just added, take a look at
-the permissions which have already been set in MySQL.
+or databases or change passwords in MariaDB. Keep in mind that we don't
+check permissions which already been set in MariaDB. So if you can't
+connect to MariaDB using the permission you just added, take a look at
+the permissions which have already been set in MariaDB.
The permission setter first reads your .my.cnf file in your Home
directory if it exists.
@@ -653,7 +653,7 @@ Options for the permission setter:
--help : print this help message and exit.
-The options shown below are used for making the connection to the MySQL
+The options shown below are used for making the connection to the MariaDB
server. Keep in mind that the permissions for the user specified via
these options must be sufficient to add users / create databases / set
passwords.
@@ -86,7 +86,7 @@ if ($opt_password eq '')
}
-# make the connection to MySQL
+# make the connection to MariaDB
$dbh= DBI->connect("DBI:mysql:mysql:host=$sqlhost:port=$opt_port:mysql_socket=$opt_socket",$opt_user,$opt_password, {PrintError => 0}) ||
die("Can't make a connection to the mysql server.\n The error: $DBI::errstr");